# bioBakery Workflows #

bioBakery Workflows is a collection of microbiome workflows. Each workflow is run with [AnADAMA2](https://bitbucket.org/biobakery/anadama2).

For detailed information, see the [bioBakery Workflows User Manual](https://bitbucket.org/biobakery/biobakery_workflows/wiki/Home).
